@@ -107,12 +107,12 @@ get_ub <- function(x) {
                     gradient = G(objective(x)),
                     hessian = hessian,
                     control = control )
-    .ROI_plugin_canonicalize_solution( solution  = out$par,
-                                       optimum   = objective(x)(out$solution),
+    ROI_plugin_canonicalize_solution( solution  = out$par,
+                                       optimum   = objective(x)(out$par),
                                        status    = out$convergence,
                                        solver    = solver,
                                        message   = out )
-    ## .ROI_plugin_canonicalize_solution( solution = out$solution,
+    ## ROI_plugin_canonicalize_solution( solution = out$solution,
     ##                                    optimum = objective(x)(out$solution),
     ##                                    status = out$convergence,
     ##                                    solver = solver,
@@ -346,7 +346,7 @@ function(x)
                              gradient = G(objective(x)),
                              #hessian = control$hessian,
                              control = control )
-    .ROI_plugin_canonicalize_solution( solution = out$solution,
+    ROI_plugin_canonicalize_solution( solution = out$solution,
                                        optimum = objective(x)(out$solution),
                                        status = out$convergence,
                                        solver = solver,
@@ -401,13 +401,13 @@ function(x)
     ## add all status codes generated by the solver to db
 
     ## Two examples are listed here:
-    .ROI_plugin_add_status_code_to_db("nlminb",
+    ROI_plugin_add_status_code_to_db("nlminb",
                                       0L,
                                       "CONVERGENCE",
                                       "Solution is optimal",
                                       0L
                                       )
-    .ROI_plugin_add_status_code_to_db("nlminb",
+    ROI_plugin_add_status_code_to_db("nlminb",
                                       1L,
                                       "NON_CONVERGENCE",
                                       "No solution."
@@ -423,11 +423,11 @@ function(x)
 
 ## based on nloptr interface
 ROI_make_NLP_FXCV_signatures <- function()
-    .ROI_plugin_make_signature( objective   = c("F"), # FIXME: c("L", "Q", "F"),
+    ROI_plugin_make_signature( objective   = c("F"), # FIXME: c("L", "Q", "F"),
                                 constraints = c("X", "F"), # FIXME: c("X", "L", "Q", "F"),
                                 types       = c("C"),
                                 bounds      = c("X", "V"),
-                                cones       = c("free"),
+                                cones       = c("X"),
                                 maximum     = c(TRUE, FALSE) )
 
 
@@ -437,20 +437,20 @@ ROI_make_NLP_FXCV_signatures <- function()
 ################################################################################
 .add_nlminb_controls <- function() {
     ## ROI + nlminb
-    .ROI_plugin_register_solver_control( "nlminb", "trace", "verbose" )
-    .ROI_plugin_register_solver_control( "nlminb", "iter.max", "max_iter" )
-    .ROI_plugin_register_solver_control( "nlminb", "rel.tol", "tol" )
-    .ROI_plugin_register_solver_control( "nlminb", "start", "start" )
+    ROI_plugin_register_solver_control( "nlminb", "trace", "verbose" )
+    ROI_plugin_register_solver_control( "nlminb", "iter.max", "max_iter" )
+    ROI_plugin_register_solver_control( "nlminb", "rel.tol", "tol" )
+    ROI_plugin_register_solver_control( "nlminb", "start", "start" )
     ## nlminb only
-    .ROI_plugin_register_solver_control( "nlminb", "hessian", "X" )
-    .ROI_plugin_register_solver_control( "nlminb", "eval.max", "X" )
-    .ROI_plugin_register_solver_control( "nlminb", "abs.tol", "X" )
-    .ROI_plugin_register_solver_control( "nlminb", "x.tol", "X" )
-    .ROI_plugin_register_solver_control( "nlminb", "xf.tol", "X" )
-    .ROI_plugin_register_solver_control( "nlminb", "step.min", "X" )
-    .ROI_plugin_register_solver_control( "nlminb", "sing.tol", "X" )
-    .ROI_plugin_register_solver_control( "nlminb", "scale.init", "X" )
-    .ROI_plugin_register_solver_control( "nlminb", "diff.g", "X" )
+    ROI_plugin_register_solver_control( "nlminb", "hessian", "X" )
+    ROI_plugin_register_solver_control( "nlminb", "eval.max", "X" )
+    ROI_plugin_register_solver_control( "nlminb", "abs.tol", "X" )
+    ROI_plugin_register_solver_control( "nlminb", "x.tol", "X" )
+    ROI_plugin_register_solver_control( "nlminb", "xf.tol", "X" )
+    ROI_plugin_register_solver_control( "nlminb", "step.min", "X" )
+    ROI_plugin_register_solver_control( "nlminb", "sing.tol", "X" )
+    ROI_plugin_register_solver_control( "nlminb", "scale.init", "X" )
+    ROI_plugin_register_solver_control( "nlminb", "diff.g", "X" )
 
     invisible( TRUE )
 }
